/*
 * This file is included by some of the Xaw3d header files. It should
 * not be included by any application code, as this would break
 * compatibility with other versions of Xaw. Application code and custom
 * widgets should test this value only if absolutely neccessary.
 */

#ifndef Xaw3dVersion

#define Xaw3dVersion	106		/* major*100 + minor */

	/* list features provided in this version */

#define	XawM			/* Athena Modern */
#define	XawTraversal		/* keyboard traversal */

#endif /* Xaw3dVersion */
